==> jarvis-meme-plugin-0.6.0.jar: jarvis/meme/helpers.clj <==
(ns jarvis.meme.helpers
  (:require [jarvis.meme.util :as util]
            [clj-http.client :as client]
            [cheshire.core :as json]
            [clojure.string :as s]))

(declare query-meme parse-image-id get-memes)

(def create-url "http://version1.api.memegenerator.net/Instance_Create?")
(def username (util/config-property "MEME_USERNAME"))
(def password (util/config-property "MEME_PASSWORD"))
(def memes (atom []))

(defn meme-query-url [meme-name] (str "http://version1.api.memegenerator.net/Generator_Select_ByUrlNameOrGeneratorID?urlName=" meme-name))
(defn list-url [page-size page-index] (str "http://version1.api.memegenerator.net/Generators_Select_ByPopular?pageIndex=" page-index "&pageSize=" page-size "&days=7"))

(defn create-meme [meme-name top-text bottom-text]
  (let [meme (query-meme (name meme-name))
        generator-id (get-in meme ["result" "generatorID"])
        image-id (parse-image-id (get-in meme ["result" "imageUrl"]))
        url (str create-url "username=" username "&password=" password "&languageCode=en&generatorID=" generator-id "&imageID=" image-id "&text0=" top-text "&text1=" bottom-text)]
    (-> url
      (client/get)
      (get :body )
      (json/decode))))

(defn query-meme [meme-name]
  (-> meme-name
    meme-query-url
    (client/get {:basic-auth [username password]})
    (get :body )
    (json/decode)))

(defn list-memes
  ([]
    (list-memes 0))
  ([page-index]
    (if (nil? page-index)
      (get-memes 20 0)
      (get-memes 20 page-index))))

(defn- get-memes [page-size page-index]
  (-> (list-url page-size page-index)
    (client/get)
    (get :body )
    (json/decode)))

(defn parse-image-id [image-url]
  (first (s/split (re-find #"\d+.jpg" image-url) #"\.")))

==> jarvis-meme-plugin-1.0.0.jar: jarvis/meme/helpers.clj <==
(ns jarvis.meme.helpers
  (:require [jarvis.meme.util :as util]
            [clj-http.client :as client]
            [cheshire.core :as json]
            [clojure.string :as s]
            [clojure.edn :as edn]))

(declare query-meme parse-image-id get-memes)

(def create-url "http://version1.api.memegenerator.net/Instance_Create?")
(def username (util/config-property "MEME_USERNAME"))
(def password (util/config-property "MEME_PASSWORD"))
(def memes (atom []))

(defn meme-query-url [meme-name] (str "http://version1.api.memegenerator.net/Generator_Select_ByUrlNameOrGeneratorID?urlName=" meme-name))
(defn list-url [page-size page-index] (str "http://version1.api.memegenerator.net/Generators_Select_ByPopular?pageIndex=" page-index "&pageSize=" page-size "&days=7"))
(defn search-url [query] (str "http://version1.api.memegenerator.net/Generators_Search?q=" query "&pageIndex=0&pageSize=24"))

(defn create-meme [meme-name top-text bottom-text]
  (let [meme (query-meme (name meme-name))
        generator-id (get-in meme ["result" "generatorID"])
        image-id (parse-image-id (get-in meme ["result" "imageUrl"]))
        url (str create-url "username=" username "&password=" password "&languageCode=en&generatorID=" generator-id "&imageID=" image-id "&text0=" top-text "&text1=" bottom-text)]
    (-> url
      (client/get)
      (get :body )
      (json/decode))))

(defn query-meme [meme-name]
  (-> meme-name
    meme-query-url
    (client/get {:basic-auth [username password]})
    (get :body )
    (json/decode)))

(defn search-memes
  ([query]
    (-> (search-url query)
      (client/get {:basic-auth [username password]})
      (get :body)
      (json/decode))))

(defn list-memes
  ([]
    (list-memes 0))
  ([page-index]
    (if (nil? page-index)
      (get-memes 20 0)
      (get-memes 20 page-index))))

(defn get-page-index [message]
  (re-find #"\d" (get message "content")))

(defn build-string [content]
  (str "[" content "]"))

(defn message->meme-vec [message substring-index]
  (-> message
    (get "content")
    (.substring substring-index)
    build-string
    (edn/read-string)))

(defn- get-memes [page-size page-index]
  (-> (list-url page-size page-index)
    (client/get)
    (get :body )
    (json/decode)))

(defn parse-image-id [image-url]
  (first (s/split (re-find #"\d+.jpg" image-url) #"\.")))
